@@ -24,9 +24,7 @@
 #include <gmodule.h>
 
 #ifdef HAVE_GTK_SOURCEVIEW
-#include <gtksourceview/gtksourceview.h>
-#include <gtksourceview/gtksourcelanguagemanager.h>
-#include <gtksourceview/gtksourcelanguage.h>
+#include <gtksourceview/gtksource.h>
 #endif
 
 #include "playlist-treeview.h"
@@ -485,8 +483,11 @@ compare_container (GtkTreeModel *model,
                             4, &container_id,
                             5, &is_container, -1);
 
-        if (!is_container)
+        if (!is_container) {
+                g_free (container_id);
+
                 return found;
+        }
 
         if (container_id == NULL)
                 return found;
